@@ -97,7 +97,7 @@ def install():
     Run pip-sync and install 'manageprojects' via pip as editable.
     """
     verbose_check_call('pip-sync', PACKAGE_ROOT / 'requirements.dev.txt')
-    verbose_check_call('pip', 'install', '-e', '.')
+    verbose_check_call('pip', 'install', '--no-deps', '-e', '.')
 
 
 cli.add_command(install)
